django-freeradius
=================

.. image:: https://travis-ci.org/openwisp/django-freeradius.svg
   :target: https://travis-ci.org/openwisp/django-freeradius

.. image:: https://coveralls.io/repos/openwisp/django-freeradius/badge.svg
  :target: https://coveralls.io/r/openwisp/django-freeradius

.. image:: https://requires.io/github/openwisp/django-freeradius/requirements.svg?branch=master
   :target: https://requires.io/github/openwisp/django-freeradius/requirements/?branch=master
   :alt: Requirements Status

.. image:: https://badge.fury.io/py/django-freeradius.svg
   :target: http://badge.fury.io/py/django-freeradius

------------

Django-freeradius is part of the `OpenWISP project <http://openwisp.org>`_.

.. image:: http://netjsonconfig.openwisp.org/en/latest/_images/openwisp.org.svg
  :target: http://openwisp.org

**django-freeradius** is Django reusable app that provides an admin interface to a `freeradius <http://freeradius.org/>`_ database.

`Documentation <http://django-freeradius.readthedocs.io/en/latest/>`_ |
`Change log <https://github.com/openwisp/django-freeradius/blob/master/CHANGES.rst>`_ |
`Support channels <http://openwisp.org/support.html>`_ |
`Issue Tracker <https://github.com/openwisp/django-freeradius/issues>`_ |
`License <https://github.com/openwisp/django-freeradius/blob/master/LICENSE>`_
